<?php
/**
 * rebar_2014 functions and definitions
 *
 * @package rebar_2014
 */

/**
 * Hide the Wordpress Admin bar.
 */
add_filter('show_admin_bar', '__return_false');

/**
 * Set the content width based on the theme's design and stylesheet.
 */
if ( ! isset( $content_width ) ) {
	$content_width = 640; /* pixels */
}

if ( ! function_exists( 'rebar_2014_setup' ) ) :
/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which
 * runs before the init hook. The init hook is too late for some features, such
 * as indicating support for post thumbnails.
 */
function rebar_2014_setup() {

	/*
	 * Make theme available for translation.
	 * Translations can be filed in the /languages/ directory.
	 * If you're building a theme based on rebar_2014, use a find and replace
	 * to change 'rebar_2014' to the name of your theme in all the template files
	 */
	load_theme_textdomain( 'rebar_2014', get_template_directory() . '/languages' );

	// Add default posts and comments RSS feed links to head.
	add_theme_support( 'automatic-feed-links' );

	/*
	 * Enable support for Post Thumbnails on posts and pages.
	 *
	 * @link http://codex.wordpress.org/Function_Reference/add_theme_support#Post_Thumbnails
	 */
	add_theme_support( 'post-thumbnails' );

	/*
	 * Add image sizes for archives.
	 */
	if ( function_exists( 'add_image_size' ) ) { 
	add_image_size( 'portfolio-thumb', 600, 400, true ); //(cropped)
}

	// This theme uses wp_nav_menu() in one location.
	register_nav_menus( array(
		'primary' => __( 'Primary Menu', 'rebar_2014' ),
	) );
	
	/*
	 * Switch default core markup for search form, comment form, and comments
	 * to output valid HTML5.
	 */
	add_theme_support( 'html5', array(
		'search-form', 'comment-form', 'comment-list', 'gallery', 'caption'
	) );

	/*
	 * Enable support for Post Formats.
	 * See http://codex.wordpress.org/Post_Formats
	 */
	add_theme_support( 'post-formats', array(
		'aside', 'image', 'video', 'quote', 'link'
	) );

	// Setup the WordPress core custom background feature.
	add_theme_support( 'custom-background', apply_filters( 'rebar_2014_custom_background_args', array(
		'default-color' => 'ffffff',
		'default-image' => '',
	) ) );
}
endif; // rebar_2014_setup
add_action( 'after_setup_theme', 'rebar_2014_setup' );

/**
 * Register widget areas.
 *
 * @link http://codex.wordpress.org/Function_Reference/register_sidebar
 */
function rebar_2014_widgets_init() {
	register_sidebar( array(
		'name'          => __( 'Sidebar', 'rebar_2014' ),
		'id'            => 'sidebar-1',
		'description'   => '',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h1 class="widget-title">',
		'after_title'   => '</h1>',
	) );
	register_sidebar( array(
		'name'          => __( 'Footer 1', 'rebar_2014' ),
		'id'            => 'footer-1',
		'description'   => '',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h1 class="widget-title">',
		'after_title'   => '</h1>',
	) );
	register_sidebar( array(
		'name'          => __( 'Footer 2', 'rebar_2014' ),
		'id'            => 'footer-2',
		'description'   => '',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h1 class="widget-title">',
		'after_title'   => '</h1>',
	) );
}
add_action( 'widgets_init', 'rebar_2014_widgets_init' );

/**
 * Enqueue scripts and styles.
 */
function rebar_2014_scripts() {
	wp_enqueue_style( 'main-style', get_stylesheet_uri() );

	wp_enqueue_style( 'foundation-style', get_template_directory_uri() . '/css/foundation.css' );

	wp_enqueue_style( 'rebar-style', get_template_directory_uri() . '/css/rebar.css' );

	wp_enqueue_script( 'modernizr', get_template_directory_uri() . '/js/vendor/modernizr.js' );

	wp_enqueue_script( 'rebar_2014-navigation', get_template_directory_uri() . '/js/navigation.js', array(), '20120206', true );

	wp_enqueue_script( 'rebar_2014-skip-link-focus-fix', get_template_directory_uri() . '/js/skip-link-focus-fix.js', array(), '20130115', true );

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
add_action( 'wp_enqueue_scripts', 'rebar_2014_scripts' );

function foundation_5_scripts() {
	echo '<!-- Foundation scripts -->
';

	wp_enqueue_script( 'foundation-jquery', get_template_directory_uri() . '/js/vendor/jquery.js' );

	wp_enqueue_script( 'fitvids', get_template_directory_uri() . '/js/vendor/jquery.fitvids.js', array( 'foundation-jquery' ) );

	wp_enqueue_script( 'foundation', get_template_directory_uri() . '/js/foundation/foundation.js', array( 'foundation-jquery' ) );

	wp_enqueue_script( 'foundation-topbar', get_template_directory_uri() . '/js/foundation/foundation.topbar.js', array( 'foundation' ) );	
}
add_action( 'wp_footer', 'foundation_5_scripts' );

/**
 * Implement the Custom Header feature.
 */
require get_template_directory() . '/inc/custom-header.php';

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Custom functions that act independently of the theme templates.
 */
require get_template_directory() . '/inc/extras.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer.php';

/**
 * Load Jetpack compatibility file.
 */
require get_template_directory() . '/inc/jetpack.php';

/**
 * Custom post types.
 */
require get_template_directory() . '/inc/portfolio-type.php';
require get_template_directory() . '/inc/tweet-type.php';

/**
 * Shortcodes.
 */
function intro_shortcode( $atts, $content = null ) {
	return '<div class="rebar-intro">' . $content . '</div>';
}
add_shortcode( 'intro', 'intro_shortcode' );

function one_half_shortcode( $atts, $content = null ) {
	return '<div class="row"><div class="large-6 medium-6 small-12 columns">' . $content . '</div>';
}
add_shortcode( 'one_half', 'one_half_shortcode' );

function one_half_last_shortcode( $atts, $content = null ) {
	$cleaned = strip_tags($content, '</p>');
	return '<div class="large-6 medium-6 small-12 columns">'. $content . '</div></div>';
}
add_shortcode( 'one_half_last', 'one_half_last_shortcode' );

/**
 * Foundation nav menu.
 */
function rebar_2014_main_nav() {
    wp_nav_menu(array(
        'container' => false,
        'container_class' => '',
        'menu' => '',
        'menu_class' => 'top-bar-menu right',
        'theme_location' => 'primary',
        'before' => '',
        'after' => '',
        'link_before' => '',
        'link_after' => '',
        'depth' => 5,
    	'fallback_cb' => false,
        'walker' => new top_bar_walker()
	));
}

/*
Customize the output of menus for Foundation top bar classes and add descriptions
http://www.kriesi.at/archives/improve-your-wordpress-navigation-menu-output
http://code.hyperspatial.com/1514/twitter-bootstrap-walker-classes/
*/
class top_bar_walker extends Walker_Nav_Menu {
    function start_el(&$output, $item, $depth, $args) {
        global $wp_query;
		
        $indent = ($depth) ? str_repeat("\t", $depth) : '';
 
        $class_names = $value = '';
 
        $classes = empty($item->classes) ? array() : (array) $item->classes;
		
	$classes[] = ($item->current) ? 'active' : '';
        $classes[] = ($args->has_children) ? 'has-dropdown' : '';
		
	$args->link_before = (in_array('section', $classes)) ? '<label>' : '';
	$args->link_after = (in_array('section', $classes)) ? '</label>' : '';
	$output .= (in_array('section', $classes)) ? '<li class="divider"></li>' : '';
 
        $class_names = join(' ', apply_filters('nav_menu_css_class', array_filter($classes), $item, $args ) );
        $class_names = strlen(trim($class_names)) > 0 ? ' class="'.esc_attr($class_names).'"' : '';
		
	$output .= ($depth == 0) ? $indent.'<li class="divider"></li>' : '';
        $output .= $indent.'<li id="menu-item-'.$item->ID.'"'.$value.$class_names.'>';
 
        $attributes  = !empty($item->attr_title) ? ' title="' .esc_attr($item->attr_title).'"' : '';
        $attributes .= !empty($item->target)     ? ' target="'.esc_attr($item->target    ).'"' : '';
        $attributes .= !empty($item->xfn)        ? ' rel="'   .esc_attr($item->xfn       ).'"' : '';
        $attributes .= !empty($item->url)        ? ' href="'  .esc_attr($item->url       ).'"' : '';
		
	$item_output  = $args->before;
	$item_output .= (!in_array('section', $classes)) ? '<a'.$attributes.'>' : '';
	$item_output .= $args->link_before.apply_filters('the_title', $item->title, $item->ID);
	$item_output .= $args->link_after;
	$item_output .= (!in_array('section', $classes)) ? '</a>' : '';
	$item_output .= $args->after;
 
        $output .= apply_filters('walker_nav_menu_start_el', $item_output, $item, $depth, $args);
    }
    function end_el(&$output, $item, $depth) {
        $output .= '</li>'."\n";
	}
    function start_lvl(&$output, $depth) {
        $indent  = str_repeat("\t", $depth);
        $output .= "\n".$indent.'<ul class="sub-menu dropdown">'."\n";
    }
    function end_lvl(&$output, $depth) {
        $indent  = str_repeat("\t", $depth);
        $output .= $indent.'</ul>'."\n";
    }		
    function display_element($element, &$children_elements, $max_depth, $depth=0, $args, &$output) {
        $id_field = $this->db_fields['id'];
        if (is_object($args[0])) {
            $args[0]->has_children = ! empty($children_elements[$element->$id_field]);
        }
        return parent::display_element($element, $children_elements, $max_depth, $depth, $args, $output);
    }  	
} // end top bar walker

/**
 * Custom header image data.
 */
// add our custom header options hook
add_action('custom_header_options', 'my_custom_image_options');
 
/* Adds two new text fields, custom_option_one and custom_option_two to the Custom Header options screen */
function my_custom_image_options()
{
?>
<table class="form-table">
	<tbody>
		<tr valign="top" class="hide-if-no-js">
			<th scope="row"><?php _e( 'Twitter username:' ); ?></th>
			<td>
				<p>
					<input type="text" name="twitter_username" id="twitter_username" value="<?php echo esc_attr( get_theme_mod( 'twitter_username', 'remotedevice' ) ); ?>" />
				</p>
			</td>
		</tr>
		<tr valign="top" class="hide-if-no-js">
			<th scope="row"><?php _e( 'LinkedIn username:' ); ?></th>
			<td>
				<p>
					<input type="text" name="linkedin_username" id="linkedin_username" value="<?php echo esc_attr( get_theme_mod( 'linkedin_username', 'remotedevice' ) ); ?>" />
				</p>
			</td>
		</tr>
		<tr valign="top" class="hide-if-no-js">
			<th scope="row"><?php _e( 'Facebook username:' ); ?></th>
			<td>
				<p>
					<input type="text" name="facebook_username" id="facebook_username" value="<?php echo esc_attr( get_theme_mod( 'facebook_username', '' ) ); ?>" />
				</p>
			</td>
		</tr>
	</tbody>
</table>
<?php
} // end my_custom_image_options
add_action('admin_head', 'save_my_custom_options');
	function save_my_custom_options()
	{
		if ( isset( $_POST['twitter_username'] ) && isset( $_POST['linkedin_username'] ) && isset( $_POST['facebook_username'] ) )
		{
			// validate the request itself by verifying the _wpnonce-custom-header-options nonce
			// (note: this nonce was present in the normal Custom Header form already, so we didn't have to add our own)
			check_admin_referer( 'custom-header-options', '_wpnonce-custom-header-options' );
 
			// be sure the user has permission to save theme options (i.e., is an administrator)
			if ( current_user_can('manage_options') ) {
 
				// NOTE: Add your own validation methods here
				set_theme_mod( 'twitter_username', $_POST['twitter_username'] );
				set_theme_mod( 'linkedin_username', $_POST['linkedin_username'] );
				set_theme_mod( 'facebook_username', $_POST['facebook_username'] );
			}
		}
		return;
	}

/**
 * Make plaintext links clickable 
 */

add_filter('the_content', 'make_clickable');
add_filter('the_excerpt', 'make_clickable');
